@@ -576,6 +576,7 @@ class SMBConnection:
 			self.selected_dialect = rply.command.DialectRevision
 			self.ServerSecurityMode = rply.command.SecurityMode
 			self.signing_required = NegotiateSecurityMode.SMB2_NEGOTIATE_SIGNING_ENABLED in rply.command.SecurityMode
+			
 					
 			if NegotiateCapabilities.ENCRYPTION in rply.command.Capabilities:
 				self.encryption_required = True
@@ -603,6 +604,7 @@ class SMBConnection:
 			self.ServerCapabilities = rply.command.Capabilities
 			#self.ClientSecurityMode = 0			
 			self.status = SMBConnectionStatus.SESSIONSETUP
+			
 			return True, None
 		
 		except Exception as e:
@@ -660,6 +662,9 @@ class SMBConnection:
 				maxiter -= 1
 			
 			if rply.header.Status == NTStatus.SUCCESS:
+				if self.gssapi.is_guest() is True:
+					self.signing_required = False
+					
 				self.SessionKey = self.gssapi.get_session_key()[:16]
 				
 				# TODO: key calc
@@ -1140,6 +1145,28 @@ class SMBConnection:
 		
 		except Exception as e:
 			return None, e
+
+	async def ioctl(self, tree_id, file_id, ctlcode, data = None, flags = IOCTLREQFlags.IS_IOCTL):
+		try:
+			command = IOCTL_REQ()
+			command.CtlCode  = ctlcode
+			command.FileId  = file_id
+			command.Flags = flags
+			command.Buffer = data
+			
+			header = SMB2Header_SYNC()
+			header.Command  = SMB2Command.IOCTL
+			header.TreeId = tree_id
+			
+			msg = SMB2Message(header, command)
+			message_id = await self.sendSMB(msg)
+
+			rply = await self.recvSMB(message_id)
+
+			return rply.command.Buffer, None
+
+		except Exception as e:
+			return None, e
 			
 	async def close(self, tree_id, file_id, flags = CloseFlag.NONE):
 		"""
